AppConstants class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

animFast → const Duration
animNormal → const Duration
animSlow → const Duration
connectTimeout → const Duration
defaultPageSize → const int
firstPage → const int
keyAccessToken → const String
keyRefreshToken → const String
keyThemeMode → const String
keyUserId → const String
receiveTimeout → const Duration