ApiClient class

Constructors

ApiClient(Dio _dio)

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

delete<T>(String path, {required T fromJson(dynamic)}) → Future<ApiResponse<T>>
get<T>(String path, {required T fromJson(dynamic), Map<String, dynamic>? queryParameters}) → Future<ApiResponse<T>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
patch<T>(String path, {required T fromJson(dynamic), dynamic data}) → Future<ApiResponse<T>>
post<T>(String path, {required T fromJson(dynamic), dynamic data}) → Future<ApiResponse<T>>
put<T>(String path, {required T fromJson(dynamic), dynamic data}) → Future<ApiResponse<T>>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Methods

create({required String baseUrl, TokenProvider? tokenProvider, TokenRefresher? tokenRefresher, bool enableLogging = true, Duration connectTimeout = const Duration(seconds: 30), Duration receiveTimeout = const Duration(seconds: 30), Map<String, dynamic>? headers}) → ApiClient