ApiException class

Implemented types

Constructors

ApiException({required String message, int? statusCode, dynamic data})
const

Properties

data → dynamic
final
hashCode → int
The hash code for this object.
no setterinherited
isForbidden → bool
no setter
isNotFound → bool
no setter
isServerError → bool
no setter
isUnauthorized → bool
no setter
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statusCode → int?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited