ApiFailure<T> class final

Inheritance
Available extensions

Constructors

ApiFailure(ApiException exception)
const

Properties

dataOrNull → T?

Available on ApiResponse<T>, provided by the ApiResponseX extension

no setter
exception → ApiException
final
exceptionOrNull → ApiException?

Available on ApiResponse<T>, provided by the ApiResponseX extension

no setter
hashCode → int
The hash code for this object.
no setterinherited
isFailure → bool

Available on ApiResponse<T>, provided by the ApiResponseX extension

no setter
isSuccess → bool

Available on ApiResponse<T>, provided by the ApiResponseX extension

no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
when<R>({required R success(T data), required R failure(ApiException exception)}) → R

Available on ApiResponse<T>, provided by the ApiResponseX extension

Operators

operator ==(Object other) → bool
The equality operator.
inherited