ApiResponse<T> class
sealed
- Implementers
- Available extensions
Properties
- dataOrNull → T?
-
Available on ApiResponse<
T> , provided by the ApiResponseX extensionno setter - exceptionOrNull → ApiException?
-
Available on ApiResponse<
T> , provided by the ApiResponseX extensionno setter - hashCode → int
-
The hash code for this object.
no setterinherited
- isFailure → bool
-
Available on ApiResponse<
T> , provided by the ApiResponseX extensionno setter - isSuccess → bool
-
Available on ApiResponse<
T> , provided by the ApiResponseX extensionno setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
R> ({required R success(T data), required R failure(ApiException exception)}) → R -
Available on ApiResponse<
T> , provided by the ApiResponseX extension
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited