AppDimensions class

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

bottomSheetRadius → const double
buttonHeight → const double
buttonHeightSm → const double
dialogMaxWidth → const double
dialogRadius → const double
iconLg → const double
iconMd → const double
iconSm → const double
lg → const double
md → const double
radiusFull → const double
radiusLg → const double
radiusMd → const double
radiusSm → const double
radiusXl → const double
sm → const double
xl → const double
xs → const double
xxl → const double