AppThemeExtension class

Inheritance

Constructors

AppThemeExtension({required Color success, required Color onSuccess, required Color warning, required Color onWarning, required Color info, required Color onInfo, required Color divider})
const
AppThemeExtension.fromScheme(AppColorScheme scheme, Brightness brightness)
factory

Properties

divider → Color
final
hashCode → int
The hash code for this object.
no setterinherited
info → Color
final
onInfo → Color
final
onSuccess → Color
final
onWarning → Color
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
success → Color
final
type → Object
The extension's type.
no setterinherited
warning → Color
final

Methods

copyWith({Color? success, Color? onSuccess, Color? warning, Color? onWarning, Color? info, Color? onInfo, Color? divider}) → AppThemeExtension
Creates a copy of this theme extension with the given fields replaced by the non-null parameter values.
override
lerp(covariant AppThemeExtension? other, double t) → AppThemeExtension
Linearly interpolate with another ThemeExtension object.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited