Validators class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
compose(
List< String? Function(String?)> validators) → String? Function(String?) - Compose multiple validators — returns first error found.
-
email(
String? value) → String? -
maxLength(
String? value, int max) → String? -
minLength(
String? value, int min) → String? -
phone(
String? value) → String? -
required(
String? value, [String message = 'This field is required']) → String? -
url(
String? value) → String?